@@ -1,4 +1,5 @@
 """Regex utils for AwesomeVersion."""
+
 import re
 from typing import Pattern
 
@@ -15,11 +16,16 @@ RE_SEMVER = (
     r"(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+([0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*))?"
 )
 RE_PEP440 = (
-    r"([1-9][0-9]*!)?(0|[1-9][0-9]*)(\.(0|[1-9][0-9]*))*((a|b|rc)"
-    r"(0|[1-9][0-9]*))?(\.post(0|[1-9][0-9]*))?(\.dev(0|[1-9][0-9]*))?(\.rc(0|[1-9][0-9]*))?"
+    r"([1-9][0-9]*!)?(0|[1-9][0-9]*)(\.(0|[1-9][0-9]*))*"  # Main segment
+    r"([-_\.]?(alpha|beta|c|pre|preview|a|b|rc)(0|[1-9][0-9]*))?"  # Pre-release segment
+    r"([-_\.]?(post|r|rev)(0|[1-9][0-9]*))?"  # Post-release segment
+    r"([-_\.]?(d|dev)(0|[1-9][0-9]*))?"  # Development release segment
+    r"(?:\+([a-z0-9]+(?:[-_\.][a-z0-9]+)*))?"  # Local version segment
 )
 RE_BUILDVER = r"\d+"
 
+RE_HEXVER = r"0x[A-Fa-f0-9]+"
+
 RE_SPECIAL_CONTAINER = r"(latest|dev|stable|beta)"
 RE_SIMPLE = r"[v|V]?((\d+)(\.\d+)+)"
 
